==> haskell-string-interpolate-0.3.4.0-137.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-string-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 string-interpolate
version:              0.3.4.0
visibility:           public
id:                   string-interpolate-0.3.4.0-8Ylcj5G5syjBAwauWVRpr1
key:                  string-interpolate-0.3.4.0-8Ylcj5G5syjBAwauWVRpr1
license:              BSD-3-Clause
copyright:            2019-2024 William Yao
maintainer:           williamyaoh@gmail.com
author:               William Yao
homepage:
    https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md

synopsis:
    Haskell string/text/bytestring interpolation that just works

description:
    Unicode-aware string interpolation that handles all textual types.

    See the README at <https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md> for more info.

category:             Data, Text
abi:                  fa991dd795f07f60796c1be6f6b18315
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.Conversion
    Data.String.Interpolate.Conversion.ByteStringSink
    Data.String.Interpolate.Conversion.TextSink
    Data.String.Interpolate.Parse Data.String.Interpolate.Types

hidden-modules:
    Data.String.Interpolate.Conversion.Classes
    Data.String.Interpolate.Conversion.Encoding
    Data.String.Interpolate.Lines Data.String.Interpolate.Whitespace
    Paths_string_interpolate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/string-interpolate-0.3.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/string-interpolate-0.3.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/string-interpolate-0.3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-interpolate
hs-libraries:         HSstring-interpolate-0.3.4.0-8Ylcj5G5syjBAwauWVRpr1
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    haskell-src-exts-1.23.1-F3jL8MeOgpf1H3BDGTEVcV
    haskell-src-meta-0.8.15-GqSWx9monJhDwN3u4roT6d
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 template-haskell-2.20.0.0
    text-2.0.2 text-conversions-0.3.1.1-K1Yt8b0G42m5WYfZmJLFVT
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y

haddock-interfaces:
    /usr/share/doc/haskell-string-interpolate/html/string-interpolate.haddock

haddock-html:         /usr/share/doc/haskell-string-interpolate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-string-interpolate-0.3.4.0-138-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-string-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 string-interpolate
version:              0.3.4.0
visibility:           public
id:                   string-interpolate-0.3.4.0-40hVGApsbsSBa1DsDPkXGs
key:                  string-interpolate-0.3.4.0-40hVGApsbsSBa1DsDPkXGs
license:              BSD-3-Clause
copyright:            2019-2024 William Yao
maintainer:           williamyaoh@gmail.com
author:               William Yao
homepage:
    https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md

synopsis:
    Haskell string/text/bytestring interpolation that just works

description:
    Unicode-aware string interpolation that handles all textual types.

    See the README at <https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md> for more info.

category:             Data, Text
abi:                  c74f275429a5b75f193f6e34244c4cd3
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.Conversion
    Data.String.Interpolate.Conversion.ByteStringSink
    Data.String.Interpolate.Conversion.TextSink
    Data.String.Interpolate.Parse Data.String.Interpolate.Types

hidden-modules:
    Data.String.Interpolate.Conversion.Classes
    Data.String.Interpolate.Conversion.Encoding
    Data.String.Interpolate.Lines Data.String.Interpolate.Whitespace
    Paths_string_interpolate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/string-interpolate-0.3.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/string-interpolate-0.3.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/string-interpolate-0.3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-interpolate
hs-libraries:         HSstring-interpolate-0.3.4.0-40hVGApsbsSBa1DsDPkXGs
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    haskell-src-exts-1.23.1-63590nDmfj1880iQCS4JdS
    haskell-src-meta-0.8.15-5WA14dofYHdB0COx7SkwL2
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 template-haskell-2.20.0.0
    text-2.0.2 text-conversions-0.3.1.1-FiAyQC2JfI11GT7GIwm2Pu
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:
    /usr/share/doc/haskell-string-interpolate/html/string-interpolate.haddock

haddock-html:         /usr/share/doc/haskell-string-interpolate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
